The Curator 🖼
==============

.. image:: https://travis-ci.org/fny/thecurator.svg?branch=master
   :target: https://travis-ci.org/fny/thecurator
   :alt: Build Status

.. image:: https://badge.fury.io/py/thecurator.svg
   :target: https://pypi.python.org/pypi/thecurator
   :alt: The Curator on PyPI


Usage
-----

See the tests. More coming soon...


Install development requirements `pip install -e .[dev]`
